#
# spec file for package lua-luasql
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2014 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor lua51%{nil}
%define flavor_dec $(c=%{flavor}; echo ${c:0:-1}.${c: -1})
%define flavor_ver %{lua:ver, ok = string.gsub(rpm.expand("%{flavor}"), "lua(%{d})(%{d})", "%{1}.%{2}"); print(ver)}
%define mod_name luasql
Version:        2.7.0
Release:        1.1
Summary:        Simple interface from Lua to a DBMS
License:        MIT
Group:          Development/Libraries/Other
URL:            https://github.com/lunarmodules/luasql
Source0:        https://github.com/lunarmodules/luasql/archive/refs/tags/%{version}/%{mod_name}-%{version}.tar.gz
# Source0:        %%{mod_name}-%%{version}.tar.gz
# PATCH-FIX-UPSTREAM add_missing_cur_gc.patch gh#lunarmodules/luasql#178 mcepl@suse.com
# add missing definition of cur_gc function
Patch0:         add_missing_cur_gc.patch
BuildRequires:  %{flavor}-devel
BuildRequires:  libiodbc-devel
BuildRequires:  libmysqlclient-devel
BuildRequires:  lua-macros
BuildRequires:  pkgconf
BuildRequires:  postgresql-devel
BuildRequires:  sqlite3-devel
Requires:       %{flavor}
Requires:       libmariadb3
%lua_provides
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif

%description
A simple interface from Lua to a DBMS. It enables a Lua program to:
 - Connect to ODBC, ADO, Oracle, MySQL, SQLite and PostgreSQL databases;
 - Execute arbitrary SQL statements;
 - Retrieve results in a row-by-row cursor fashion.

%prep
%autosetup -p1 -n %{mod_name}-%{version}

%build
export OPTFLAGS="%{optflags}"
export LUA_INC="%{lua_incdir}"

# also oci8 firebird
%make_build \
    DRIVER_INCS="-I%{_includedir}" DRIVER_LIBS_sqlite3="-lsqlite3" sqlite3
%make_build \
    DRIVER_INCS="-I%{_includedir}/pgsql" DRIVER_LIBS_postgres="-lpq" postgres
%make_build \
    DRIVER_INCS="-I%{_includedir}/mysql" DRIVER_LIBS_mysql="-lmysqlclient -lz" mysql
%make_build \
    DRIVER_INCS="-I%{_includedir}" DRIVER_LIBS_odbc="-liodbc" odbc

%install
%make_install LUA_LIBDIR='$(DESTDIR)%{lua_archdir}' sqlite3
%make_install LUA_LIBDIR='$(DESTDIR)%{lua_archdir}' postgres
%make_install LUA_LIBDIR='$(DESTDIR)%{lua_archdir}' mysql
%make_install LUA_LIBDIR='$(DESTDIR)%{lua_archdir}' odbc

%check
export LUA_PATH='%{buildroot}%{lua_archdir}/?.lua;;'
export LUA_CPATH='%{buildroot}%{lua_archdir}/?.so'
lua%{lua_version} tests/test.lua sqlite3

%files
%doc doc/us/*
%dir %{lua_archdir}/luasql
%{lua_archdir}/luasql/
# TODO? Split to subpackages?
# /usr/lib64/lua/%%{lua_version}/luasql
# /usr/lib64/lua/%%{lua_version}/luasql/mysql.so
# /usr/lib64/lua/%%{lua_version}/luasql/postgres.so
# /usr/lib64/lua/%%{lua_version}/luasql/sqlite3.so

%changelog
* Tue Jul  8 2025 Matej Cepl <mcepl@cepl.eu>
- Update to 2.7.0:
  * LuaSQL is adapted to Lua version 5.4 and all the drivers are
    compatible with To-be-closed variables.
  * The :close() method now returns false and a string with
    appropriate message instead of raising an error when there
    are related open objects.
- Add add_missing_cur_gc.patch adding missing cur_gc symbol
  (gh#lunarmodules/luasql#178).
* Tue Nov  5 2024 Matej Cepl <mcepl@cepl.eu>
- Switch to _service and download the code from GitHub repo,
  upstream doesn't create releases.
- Update to version 2.6.0+git.1724375068.d60f8b2:
  * Add version history and credits
  * Update fr Documentation
  * Update br Documentation
  * Update US Documentation
  * Minor fixes
  * Fix HTML Characters
  * Update br Documentation
  * Update Fr Documentation
  * Update example
- Enable the test suite.
- Remove already upstreamed luasql-fix-configuration.patch
* Fri Mar 17 2023 Matej Cepl <mcepl@suse.com>
- Update to 2.6.0:
  - Added read-only mode to SQLite3 and two new methods to MySQL
    fetch.
  - This release also added the library opening functions to
    luasql.h in order to ease the initialization process in C
    applications.
  - Added seek method to MySQL driver and bug-fix on ODBC driver
    number retrieval.
- Clean up luasql-fix-configuration.patch (now on
  gh#lunarmodules/luasql!152).
* Thu Mar 16 2023 Matej Cepl <mcepl@suse.com>
- Change upstream homepage to the current one at Lunar Modules.
* Thu Feb 18 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%lua_provides macro for default lua versioning
* Mon Jul  6 2020 Matej Cepl <mcepl@suse.com>
- Add lua54 as new build target
* Wed Dec  5 2018 mcepl@suse.com
- Upgrade to 2.4.0:
  * Added support in MySQL driver for opening a connection
    based on a Unix socket (thanks to rafis)
  * Added connection ping method (thanks to rafis)
  * Added Makefile for mingw (thanks to watercoldyi)
  * Bug correction on retrieving varchar2 data (thanks to David
    Gao)
- Rewrite to multibuild, standard openSUSE Lua SPEC file.
* Sat Feb  8 2014 malcolmlewis@opensuse.org
- Initial build.
- Add luasql-fix-configuration.patch: Clean up building and add rpm
  optflags.
